Mixing positional and keyword arguments for ``legend`` handles and labels...
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
... is no longer valid.  If passing *handles* and *labels* to ``legend``, they must
now be passed either both positionally or both as keywords.

Legend labels for ``plot``
~~~~~~~~~~~~~~~~~~~~~~~~~~
Previously if a sequence was passed to the *label* parameter of `~.Axes.plot` when
plotting a single dataset, the sequence was automatically cast to string for the legend
label.  Now, if the sequence length is not one an error is raised.  To keep the old
behavior, cast the sequence to string before passing.
